import { BehaviorSubject } from 'rxjs';
export declare type ColumnConfig = {
    columnWidth?: string;
    textContent?: {
        header?: boolean;
        isHeaderLink?: boolean;
        headerLink?: string;
        title?: string;
        body?: boolean;
        isBodyLink?: boolean;
        bodyLinkProperty?: string | null;
        queryParamsProperty?: string;
        contentProperty?: string;
        isBodyAction?: boolean;
        alias?: string;
        material?: boolean;
        showMoreText?: boolean;
        isStatus?: boolean;
    };
    inputContent?: {
        body?: boolean;
        type?: string;
        formControlProperty?: string;
        placeholder?: string;
        valuesStreamProperty?: string;
        iconProperty?: string;
        showIcon?: boolean;
        isMaterialIcon?: boolean;
        minQuantity?: number;
        maxQuantity?: number;
    };
    HTMLContent?: {
        header?: boolean;
        isHeaderLink?: boolean;
        headerLink?: string;
        title?: string;
        body?: boolean;
        contentProperty?: string;
    };
    iconsContent?: {
        header?: boolean;
        headerClass?: string;
        isHeaderLink?: boolean;
        headerLink?: string;
        body?: boolean;
        bodyProperties?: Array<string>;
        isBodyLink?: boolean;
        bodyLinkProperty?: string;
        titleProperty?: string;
        title?: string;
        isBodyAction?: string;
        material?: boolean;
    };
    wrapper?: {
        class?: string;
        classProperty?: string;
    };
    tooltipContent?: {
        tooltip?: boolean;
        iconContent?: string;
        text?: string;
        body?: boolean;
        contentProperty?: 'name';
    };
    imagesContent?: {
        header?: boolean;
        headerUrl?: string;
        isHeaderLink?: boolean;
        headerLink?: string;
        body?: boolean;
        bodyProperties?: Array<string>;
        isBodyLink?: boolean;
        bodyLinkProperty?: string;
    };
    wrapperLink?: {
        header?: boolean;
        headerLink?: string;
        body?: boolean;
        bodyLinkProperty?: string;
        isHeaderLink?: boolean;
        isBodyLink?: boolean;
    };
    buttonsContent?: {
        body?: boolean;
        class?: string;
        buttonList?: Array<{
            showMatTooltip?: boolean;
            class?: string;
            showProperty?: string;
            icon?: string;
            title?: string;
            alias?: string;
            iconClass?: string;
        }>;
        textButtonsList?: Array<{
            showProperty?: string;
            text?: string;
            alias?: string;
        }>;
        select?: {
            useClear?: boolean;
            clearLikeOption?: boolean;
            multiple?: boolean;
            search?: boolean;
            placeholder?: string;
            availableData$: BehaviorSubject<any[]>;
            defaultValue?: string;
            alias?: string;
        };
        togglTextButtonsList?: Array<{
            showProperty?: string;
            textOn?: string;
            textOff?: string;
            textOnClass?: string;
            textOffClass?: string;
            alias?: string;
            toggledProperty?: string;
        }>;
        textButtonList?: Array<{
            showProperty?: boolean;
            alias?: string;
            text?: string;
        }>;
        togglTextButtonList?: Array<{
            spinner?: boolean;
            showProperty?: string;
            alias?: string;
            class?: string;
            textOn?: string;
            textOff?: string;
            textOnClass?: string;
            textOffClass?: string;
            toggledProperty?: string;
        }>;
    };
    labelContent?: {
        body?: boolean;
        labels: string[];
        valueProperty?: string;
        titleProperty?: string;
        contentProperty?: string;
        backgroundProperty?: string;
    };
    endpointsListContent?: {
        body?: string;
        name?: string;
        link?: string;
        contentProperty?: string;
    };
    videosContent?: {
        body?: string;
        isBodyLink?: string;
        bodyProperties?: string;
    };
    checkboxContent?: {
        header?: boolean;
        body: boolean;
        checked?: boolean;
        disabledCheckbox?: boolean;
        checkboxMessage?: string;
        headerCheckboxMessage?: string;
        contentProperty?: string;
    };
    customClass?: {
        bodyClassProperty?: string;
    };
    tdCustomClass?: {
        tdCustomClassProperty?: string;
    };
    sort?: {
        active?: boolean;
        reverseSort?: boolean;
        sortKey?: string;
    };
    filter?: {
        active?: boolean;
        alias?: string;
        activeValueAlias?: string;
        filterList?: Array<{
            key?: string;
            title?: string;
            name?: string;
            class?: string;
            description?: string;
        }>;
    };
    commonOptions?: {
        class: string;
    };
};
export declare type ConfigTable = {
    showDefaultPlaceholder?: boolean;
    pagination?: {
        enabled: boolean;
        perPage: number;
        paginatorDropdownEnabled?: boolean;
        pageValue?: number;
    };
    isActiveCustomization?: boolean;
    tableName?: string;
    columnsConfig?: Array<ColumnConfig>;
    fixedRow?: {
        top?: boolean;
        bottom?: boolean;
        class?: string;
        cells?: {
            [key: string]: any;
        };
    };
    cellsVerticalAlign?: 'top' | 'middle';
    warningArray?: string;
    warningMessage?: string;
    warningIcon?: string;
    warningClass?: string;
    activeClass?: string;
};
export declare type FunctionList = {
    [key: string]: Function;
};
export declare type ValueList = {
    [key: string]: string;
};
export declare type TableWarning = {
    warningMessage: string;
    warningIcon: string;
    warningClass: string;
};
export declare type FormConfig = {
    name: string;
    selected: boolean;
};
export declare enum FILTER_STATUSES_ENUM {
    ALL = "all",
    ACTIVE = "ACTIVE",
    PAUSED = "PAUSED",
    DISAPPROVED = "DISAPPROVED",
    PENDING_APPROVAL = "PENDING_APPROVAL"
}
